import {
  IgrColumn,
  IgrGrid,
  IgrGridModule,
  IgrGridState,
} from "@infragistics/igniteui-react-grids";

import { DATA } from "./assets/data.js";
import { useRef } from "react";
import { IgrButton } from "@infragistics/igniteui-react";
import "./index.css";

import "@infragistics/igniteui-react-grids/grids/combined";
import "@infragistics/igniteui-react-grids/grids/themes/light/bootstrap.css";

IgrGridModule.register();

function App() {
  let gridRef = useRef<IgrGrid>(null);
  let gridStateRef = useRef<IgrGridState>(null);

  const stateKey = "grid1-state";

  function saveGridState() {
    const state = gridStateRef.current.getStateAsString([]);
    window.localStorage.setItem(stateKey, state);
  }

  function restoreGridState() {
    const state = window.localStorage.getItem(stateKey);
    if (state) {
      gridStateRef.current.applyStateFromString(state, []);
      gridRef.current.getColumnByName("ID").cellClasses = cellClassesHandler;
    }
  }

  function clearStorage() {
    window.localStorage.removeItem(stateKey);
  }

  const cellClassesHandler = {
    cellBackground: (
      rowData: any,
      columnKey: string,
      cellValue: any,
      rowIndex: number
    ) => cellValue < 4,
  };

  return (
    <>
      <div className="buttons-container">
        <IgrButton key="restoreBtn" clicked={restoreGridState}>
          <span key="restore">Restore</span>
        </IgrButton>
        <IgrButton key="saveBtn" clicked={saveGridState}>
          <span key="save">Save</span>
        </IgrButton>
        <IgrButton key="clearBtn" clicked={clearStorage}>
          <span key="clear">Clear</span>
        </IgrButton>
      </div>

      <IgrGrid
        autoGenerate="false"
        ref={gridRef}
        data={DATA}
        height="480px"
        width="100%"
        allowFiltering="true"
      >
        <IgrGridState ref={gridStateRef}></IgrGridState>
        <IgrColumn
          field="ID"
          header="Product ID"
          cellClasses={cellClassesHandler}
        ></IgrColumn>
        <IgrColumn
          field="ProductName"
          header="Product Name"
          sortable="true"
        ></IgrColumn>
        <IgrColumn
          field="UnitsInStock"
          header="Units In Stock"
          dataType="number"
          sortable="true"
        ></IgrColumn>
        <IgrColumn
          field="UnitPrice"
          header="Units Price"
          dataType="number"
        ></IgrColumn>
        <IgrColumn field="QuantityPerUnit"></IgrColumn>
        <IgrColumn field="ReorderLevel" dataType="number"></IgrColumn>
      </IgrGrid>
    </>
  );
}

export default App;
